==> tidalcycles-1.4.8-11-x86_64.pkg.tar.zst: usr/share/haskell/register/tidalcycles.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tidal
version:              1.4.8
visibility:           public
id:                   tidal-1.4.8-A4J5y1wBLoi6FdVMRHR8Y2
key:                  tidal-1.4.8-A4J5y1wBLoi6FdVMRHR8Y2
license:              GPL-3.0-only
copyright:            (c) Tidal contributors, 2019
maintainer:
    Alex McLean <alex@slab.org>, Mike Hodnick <mike.hodnick@gmail.com>

author:               Alex McLean
stability:            Experimental
homepage:             http://tidalcycles.org/
synopsis:             Pattern language for improvised music
description:
    Tidal is a domain specific language for live coding pattern.

category:             Sound
abi:                  090ec1c3833b5e761c32ee14482fcbb3
exposed:              True
exposed-modules:
    Sound.Tidal.Bjorklund Sound.Tidal.Carabiner Sound.Tidal.Chords
    Sound.Tidal.Config Sound.Tidal.Context Sound.Tidal.Control
    Sound.Tidal.Core Sound.Tidal.EspGrid Sound.Tidal.Params
    Sound.Tidal.ParseBP Sound.Tidal.Pattern Sound.Tidal.Scales
    Sound.Tidal.Simple Sound.Tidal.Stream Sound.Tidal.Tempo
    Sound.Tidal.Transition Sound.Tidal.UI Sound.Tidal.Utils
    Sound.Tidal.Version

import-dirs:          /usr/lib/ghc-8.8.3/site-local/tidal-1.4.8
library-dirs:         /usr/lib/ghc-8.8.3/site-local/tidal-1.4.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/tidal-1.4.8
hs-libraries:         HStidal-1.4.8-A4J5y1wBLoi6FdVMRHR8Y2
depends:
    base-4.13.0.0 bifunctors-5.5.7-11dbXkl0Czj9fLadSbCufo
    bytestring-0.10.10.0 clock-0.8-BDr0ZJKaVWEAskyGHHBCXi
    colour-2.3.5-InZKMjt87kp7jWJjBLswr9 containers-0.6.2.1
    deepseq-1.4.4.0 hosc-0.17-BTeaWWz8ldKEFC7atll44w
    mwc-random-0.14.0.0-FzP4oQi6Xal5FS9XPNzuI9
    network-2.8.0.1-Az808FcmCtCG39ffXHH2Iq parsec-3.1.14.0
    primitive-0.7.0.1-CN4ea3Jrhra6yENuqrDg51
    random-1.1-CUqV1zxrwrE4K5XCdTZSYy text-1.2.4.0 transformers-0.5.6.2
    vector-0.12.1.2-C2W44iPdAFeHo4yLU081Gd

haddock-interfaces:   /usr/share/doc/tidalcycles/html/tidal.haddock
haddock-html:         /usr/share/doc/tidalcycles/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> tidalcycles-1.4.8-13-x86_64.pkg.tar.zst: usr/share/haskell/register/tidalcycles.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tidal
version:              1.4.8
visibility:           public
id:                   tidal-1.4.8-B5AKLXQEiP07kKtwt0dwEE
key:                  tidal-1.4.8-B5AKLXQEiP07kKtwt0dwEE
license:              GPL-3.0-only
copyright:            (c) Tidal contributors, 2019
maintainer:
    Alex McLean <alex@slab.org>, Mike Hodnick <mike.hodnick@gmail.com>

author:               Alex McLean
stability:            Experimental
homepage:             http://tidalcycles.org/
synopsis:             Pattern language for improvised music
description:
    Tidal is a domain specific language for live coding pattern.

category:             Sound
abi:                  ce1e7832dc8b8bccabc2146422e6ef8c
exposed:              True
exposed-modules:
    Sound.Tidal.Bjorklund Sound.Tidal.Carabiner Sound.Tidal.Chords
    Sound.Tidal.Config Sound.Tidal.Context Sound.Tidal.Control
    Sound.Tidal.Core Sound.Tidal.EspGrid Sound.Tidal.Params
    Sound.Tidal.ParseBP Sound.Tidal.Pattern Sound.Tidal.Scales
    Sound.Tidal.Simple Sound.Tidal.Stream Sound.Tidal.Tempo
    Sound.Tidal.Transition Sound.Tidal.UI Sound.Tidal.Utils
    Sound.Tidal.Version

import-dirs:          /usr/lib/ghc-8.8.3/site-local/tidal-1.4.8
library-dirs:         /usr/lib/ghc-8.8.3/site-local/tidal-1.4.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/tidal-1.4.8
hs-libraries:         HStidal-1.4.8-B5AKLXQEiP07kKtwt0dwEE
depends:
    base-4.13.0.0 bifunctors-5.5.7-7QenYuBhOhMEcCq6CQlHUR
    bytestring-0.10.10.0 clock-0.8-BDr0ZJKaVWEAskyGHHBCXi
    colour-2.3.5-CeVMVvsoUiEFj0OOQJ5dVv containers-0.6.2.1
    deepseq-1.4.4.0 hosc-0.17-6U2wDI863he1ndNXaLiSbn
    mwc-random-0.14.0.0-Eb8dmvCTAu28qpslf89kT3
    network-3.1.1.1-6PUzEyI3Oz6H5EpZoylDU1 parsec-3.1.14.0
    primitive-0.7.0.1-CN4ea3Jrhra6yENuqrDg51
    random-1.1-CUqV1zxrwrE4K5XCdTZSYy text-1.2.4.0 transformers-0.5.6.2
    vector-0.12.1.2-C2W44iPdAFeHo4yLU081Gd

haddock-interfaces:   /usr/share/doc/tidalcycles/html/tidal.haddock
haddock-html:         /usr/share/doc/tidalcycles/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
